#ifndef COMPAT_H
#define COMPAT_H

#ifndef LINUX_VERSION_CODE
#include <linux/version.h>
#endif

/* Backwards compatibility tricks (thanks to Alex <sud@latinsud.com>) */
#if LINUX_VERSION_CODE < KERNEL_VERSION(2,4,23)
typedef void irqreturn_t;
#define IRQ_NONE
#define IRQ_HANDLED
#define IRQ_RETVAL(x)
#define free_netdev(x) kfree(x)
#define pci_name(x) x->slot_name
#endif

#if LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0)
#define pci_set_consistent_dma_mask(x,y)
#define module_param(x,y,z) MODULE_PARM(x, "i")
#define del_singleshot_timer_sync(x) del_timer_sync(x)

#ifndef SET_NETDEV_DEV
#define SET_NETDEV_DEV(net, pdev)
#endif

#ifndef HAVE_NETDEV_PRIV
#define netdev_priv(x) x->priv
#endif

#include <linux/random.h>

/**
 * random_ether_addr - Generate software assigned random Ethernet address
 * @addr: Pointer to a six-byte array containing the Ethernet address
 *
 * Generate a random Ethernet address (MAC) that is not multicast
 * and has the local assigned bit set.
 */
static inline void random_ether_addr(u8 *addr)
{
        get_random_bytes (addr, ETH_ALEN);
        addr [0] &= 0xfe;       /* clear multicast bit */
        addr [0] |= 0x02;       /* set local assignment bit (IEEE802) */
}

#endif

#endif /* COMPAT_H */
